package com.ruoyi.pay.controller;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.pay.domain.vo.PayDayWorkHoursVo;
import com.ruoyi.pay.domain.bo.PayDayWorkHoursBo;
import com.ruoyi.pay.service.IPayDayWorkHoursService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 日工工时
 *
 * @author ruoyi
 * @date 2025-05-12
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/pay/dayWorkHours")
public class PayDayWorkHoursController extends BaseController {

    private final IPayDayWorkHoursService iPayDayWorkHoursService;

    /**
     * 查询日工工时列表
     */
    @SaCheckPermission("pay:dayWorkHours:list")
    @GetMapping("/list")
    public TableDataInfo<PayDayWorkHoursVo> list(PayDayWorkHoursBo bo, PageQuery pageQuery) {
        return iPayDayWorkHoursService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出日工工时列表
     */
    @SaCheckPermission("pay:dayWorkHours:export")
    @Log(title = "日工工时", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(PayDayWorkHoursBo bo, HttpServletResponse response) {
        List<PayDayWorkHoursVo> list = iPayDayWorkHoursService.queryList(bo);
        ExcelUtil.exportExcel(list, "日工工时", PayDayWorkHoursVo.class, response);
    }

    /**
     * 获取日工工时详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("pay:dayWorkHours:query")
    @GetMapping("/{id}")
    public R<PayDayWorkHoursVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable Long id) {
        return R.ok(iPayDayWorkHoursService.queryById(id));
    }

    /**
     * 新增日工工时
     */
    @SaCheckPermission("pay:dayWorkHours:add")
    @Log(title = "日工工时", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody PayDayWorkHoursBo bo) {
        return toAjax(iPayDayWorkHoursService.insertByBo(bo));
    }

    /**
     * 修改日工工时
     */
    @SaCheckPermission("pay:dayWorkHours:edit")
    @Log(title = "日工工时", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody PayDayWorkHoursBo bo) {
        return toAjax(iPayDayWorkHoursService.updateByBo(bo));
    }

    /**
     * 删除日工工时
     *
     * @param ids 主键串
     */
    @SaCheckPermission("pay:dayWorkHours:remove")
    @Log(title = "日工工时", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable Long[] ids) {
        return toAjax(iPayDayWorkHoursService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
